==> android-sdk-2.4.0.2-sources.jar: io/adbrix/sdk/data/dataprovider/GoogleAdvertisingIdProvider.java <==
package io.adbrix.sdk.data.dataprovider;

import android.content.ContentResolver;
import android.content.Context;
import android.os.Build;
import android.provider.Settings;

import com.google.android.gms.ads.identifier.AdvertisingIdClient;

import java.util.Arrays;

import io.adbrix.sdk.component.AbxLog;
import io.adbrix.sdk.utils.CommonUtils;

public class GoogleAdvertisingIdProvider implements IGoogleAdvertisingIdProvider {

    private Context context;
    private AdInfo adInfo;
    public GoogleAdvertisingIdProvider(Context context) {
        this.context = context;
        this.adInfo = null;
    }

    public void requestAdInfo(Callback callback){
        AdvertisingIdClient.Info info = null;

        try {
            info = AdvertisingIdClient.getAdvertisingIdInfo(context);
        } catch (Exception e) {
            AbxLog.w(e, true);
        }

        if (info != null && !CommonUtils.isNullOrEmpty(info.getId())) {
            callback.getAdInfo(new AdInfo(info.getId(), info.isLimitAdTrackingEnabled()));
        } else if ("Amazon".equals(Build.MANUFACTURER)) {
            ContentResolver contentResolver = context.getContentResolver();
            callback.getAdInfo(new AdInfo(
                    Settings.Secure.getString(contentResolver, "advertising_id"),
                    Settings.Secure.getInt(contentResolver, "limit_ad_tracking", 0) == 1));
        } else {
            callback.getAdInfo(new AdInfo(null, true));
        }
    }

    @Override
    public AdInfo getAdInfo() {
        return this.adInfo;
    }
}

==> android-sdk-2.5.0.9-sources.jar: io/adbrix/sdk/data/dataprovider/GoogleAdvertisingIdProvider.java <==
package io.adbrix.sdk.data.dataprovider;

import android.content.ContentResolver;
import android.content.Context;
import android.os.Build;
import android.provider.Settings;

import com.google.android.gms.ads.identifier.AdvertisingIdClient;

import java.util.Arrays;

import io.adbrix.sdk.component.AbxLog;
import io.adbrix.sdk.utils.CommonUtils;

public class GoogleAdvertisingIdProvider implements IGoogleAdvertisingIdProvider {

    private Context context;
    private AdInfo adInfo;
    public GoogleAdvertisingIdProvider(Context context) {
        this.context = context;
        this.adInfo = null;
    }
    @Override
    public void requestAdInfo(IDataProviderResultListener listener, Callback callback){
        AdvertisingIdClient.Info info = null;

        try {
            info = AdvertisingIdClient.getAdvertisingIdInfo(context);
        } catch (Exception e) {
            AbxLog.w(e, true);
        }

        if (info != null && !CommonUtils.isNullOrEmpty(info.getId())) {
            callback.getAdInfo(new AdInfo(info.getId(), info.isLimitAdTrackingEnabled()));
        } else if ("Amazon".equals(Build.MANUFACTURER)) {
            ContentResolver contentResolver = context.getContentResolver();
            callback.getAdInfo(new AdInfo(
                    Settings.Secure.getString(contentResolver, "advertising_id"),
                    Settings.Secure.getInt(contentResolver, "limit_ad_tracking", 0) == 1));
        } else {
            callback.getAdInfo(new AdInfo(null, true));
        }
    }

    @Override
    public AdInfo getAdInfo() {
        return this.adInfo;
    }
}
